@@ -8,7 +8,7 @@ module Test.Tasty.CmdLine
   ) where
 
 import Options.Applicative
-import Data.Monoid
+import Data.Monoid ((<>))
 import Data.Proxy
 import Data.Foldable (foldMap)
 import Prelude  -- Silence AMP and FTP import warnings
@@ -29,6 +29,9 @@ import Data.Typeable (Typeable)
 import System.Posix.Signals
 import System.Mem.Weak (deRefWeak)
 #endif
+#if !MIN_VERSION_base(4,9,0)
+import Data.Monoid
+#endif
 
 import Test.Tasty.Core
 import Test.Tasty.Ingredients
